mpl-svg  [![Version](https://img.shields.io/pypi/v/mpl-svg)](https://pypi.org/project/mpl-svg/#history) 
[![PyPi - Downloads](https://img.shields.io/pypi/dm/mpl-svg)](https://pypi.org/project/mpl-svg/#files)
============

Reformat Matplotlib SVGs for easier access and customzation with CSS

## Installation
Install [mpl-svg](https://pypi.org/project/mpl-svg/) with pip:
```bash
pip install mpl-svg
```

## License
This project is licensed under the [MIT License](LICENSE.txt)